@@ -11,13 +11,14 @@
 #include "arpeggio.hh"
 #include "context.hh"
 #include "engraver.hh"
+#include "international.hh"
+#include "music.hh"
+#include "pitch.hh"
 #include "protected-scm.hh"
 #include "rhythmic-head.hh"
 #include "side-position-interface.hh"
 #include "tie.hh"
 #include "warn.hh"
-#include "music.hh"
-#include "pitch.hh"
 
 #include "translator.icc"
 
@@ -235,7 +236,7 @@ number_accidentals (bool *different,
   *different = false;
   if (scm_is_pair (accidentals) && !scm_is_symbol (scm_car (accidentals)))
     warning (_f ("accidental typesetting list must begin with context-name: %s",
-		 ly_scm2string (scm_car (accidentals)).to_str0 ()));
+		 ly_scm2string (scm_car (accidentals)).c_str ()));
 
   for (; scm_is_pair (accidentals) && origin;
        accidentals = scm_cdr (accidentals))
@@ -263,7 +264,7 @@ number_accidentals (bool *different,
 	    }
 	  else
 	    warning (_f ("ignoring unknown accidental: %s",
-			 ly_symbol2string (type).to_str0 ()));
+			 ly_symbol2string (type).c_str ()));
 	}
 
       /* if symbol then it is a context name.  Scan parent contexts to
@@ -279,7 +280,7 @@ number_accidentals (bool *different,
 	}
       else
 	warning (_f ("pair or context-name expected for accidental rule, found %s",
-		     ly_scm2string (rule).to_str0 ()));
+		     ly_scm2string (rule).c_str ()));
     }
 
   return number;
@@ -531,7 +532,7 @@ Accidental_engraver::acknowledge_rhythmic_head (Grob_info info)
       && note->is_mus_type ("note-event"))
     {
       /*
-	String harmonics usually don't have accidentals.
+	std::string harmonics usually don't have accidentals.
       */
       if (to_boolean (get_property ("harmonicAccidentals"))
 	  || !ly_is_equal (info.grob ()->get_property ("style"),
