@@ -12,7 +12,7 @@ using namespace std;
 #include "binary-source-file.hh"
 #include "string-convert.hh"
 
-Binary_source_file::Binary_source_file (String &file_name_string)
+Binary_source_file::Binary_source_file (std::string &file_name_string)
   : Source_file (file_name_string)
 {
 }
@@ -21,28 +21,28 @@ Binary_source_file::~Binary_source_file ()
 {
 }
 
-String
+std::string
 Binary_source_file::quote_input (char const *pos_str0) const
 {
   assert (this);
   if (!contains (pos_str0))
     return "";
 
-  char const *begin_str0 = max (pos_str0 - 8, to_str0 ());
-  char const *end_str0 = min (pos_str0 + 7, to_str0 () + length ());
+  char const *begin_str0 = max (pos_str0 - 8, c_str ());
+  char const *end_str0 = min (pos_str0 + 7, c_str () + length ());
 
-  String pre_string ((Byte const *)begin_str0, pos_str0 - begin_str0);
+  std::string pre_string (begin_str0, pos_str0 - begin_str0);
   pre_string = String_convert::bin2hex (pre_string);
-  for (int i = 2; i < pre_string.length (); i += 3)
-    pre_string = pre_string.left_string (i)
-      + " " + pre_string.cut_string (i, INT_MAX);
-  String post_string ((Byte const *)pos_str0, end_str0 - pos_str0);
+  for (ssize i = 2; i < pre_string.length (); i += 3)
+    pre_string = pre_string.substr (0, i)
+      + " " + pre_string.substr (i, NPOS);
+  std::string post_string (pos_str0, end_str0 - pos_str0);
   post_string = String_convert::bin2hex (post_string);
-  for (int i = 2; i < post_string.length (); i += 3)
-    post_string = post_string.left_string (i)
-      + " " + post_string.cut_string (i, INT_MAX);
+  for (ssize i = 2; i < post_string.length (); i += 3)
+    post_string = post_string.substr (0, i)
+      + " " + post_string.substr (i, NPOS);
 
-  String str = pre_string
+  std::string str = pre_string
     + to_string ('\n')
     + to_string (' ', pre_string.length () + 1)
     + post_string;
@@ -55,7 +55,7 @@ Binary_source_file::get_line (char const *pos_str0) const
   if (!contains (pos_str0))
     return 0;
 
-  return pos_str0 - to_str0 ();
+  return pos_str0 - c_str ();
 }
 
 U8
