@@ -12,11 +12,13 @@
 using namespace std;
 
 #include "config.hh"
+
 #include "file-path.hh"
+#include "international.hh"
+#include "main.hh"
 #include "source-file.hh"
 #include "source.hh"
 #include "warn.hh"
-#include "main.hh"
 
 #ifndef YY_BUF_SIZE
 #define YY_BUF_SIZE 16384
@@ -44,22 +46,22 @@ Includable_lexer::Includable_lexer ()
 
 /** Set the new input file to NAME, remember old file.  */
 void
-Includable_lexer::new_input (String name, Sources *sources)
+Includable_lexer::new_input (std::string name, Sources *sources)
 {
   if (!allow_includes_b_)
     {
-      LexerError (_ ("include files are not allowed in safe mode").to_str0 ());
+      LexerError (_ ("include files are not allowed in safe mode").c_str ());
       return;
     }
 
   Source_file *file = sources->get_file (name);
   if (!file)
     {
-      String msg = _f ("can't find file: `%s'", name);
+      std::string msg = _f ("can't find file: `%s'", name);
       msg += "\n";
       msg += _f ("(search path: `%s')",
-		 sources->path_->to_string ().to_str0 ());
-      LexerError (msg.to_str0 ());
+		 sources->path_->to_string ().c_str ());
+      LexerError (msg.c_str ());
       return;
     }
   file_name_strings_.push (file->name_string ());
@@ -69,7 +71,7 @@ Includable_lexer::new_input (String name, Sources *sources)
     state_stack_.push (yy_current_buffer);
 
   if (be_verbose_global)
-    progress_indication (String ("[") + name);
+    progress_indication (std::string ("[") + name);
 
   include_stack_.push (file);
 
@@ -81,7 +83,7 @@ Includable_lexer::new_input (String name, Sources *sources)
 }
 
 void
-Includable_lexer::new_input (String name, String data, Sources *sources)
+Includable_lexer::new_input (std::string name, std::string data, Sources *sources)
 {
   Source_file *file = new Source_file (name, data);
   sources->add (file);
@@ -92,7 +94,7 @@ Includable_lexer::new_input (String name, String data, Sources *sources)
     state_stack_.push (yy_current_buffer);
 
   if (be_verbose_global)
-    progress_indication (String ("[") + name);
+    progress_indication (std::string ("[") + name);
   include_stack_.push (file);
 
   yy_switch_to_buffer (yy_create_buffer (file->get_istream (), YY_BUF_SIZE));
@@ -128,7 +130,7 @@ Includable_lexer::here_str0 () const
 {
   if (include_stack_.is_empty ())
     return 0;
-  return include_stack_.top ()->to_str0 () + char_count_stack_.top ();
+  return include_stack_.top ()->c_str () + char_count_stack_.top ();
 }
 
 Includable_lexer::~Includable_lexer ()
