@@ -76,7 +76,12 @@ Note_spacing::get_spacing (Grob *me, Item *right_col,
 		first note head will be.
 	      */
 	      if (g)
-		left_head_wid = g->extent (it_col, X_AXIS);
+		{
+		  if (g->common_refpoint (it_col, X_AXIS) != it_col)
+		    programming_error ("Note_spacing::get_spacing(): Common refpoint incorrect");
+		  else
+		    left_head_wid = g->extent (it_col, X_AXIS);
+		}
 	    }
 
 	  extents[d].unite (it->extent (it_col, X_AXIS));
