@@ -12,6 +12,7 @@
 #include "output-def.hh"
 #include "ly-module.hh"
 #include "context-def.hh"
+#include "lily-parser.hh"
 
 LY_DEFINE (ly_layout_lookup, "ly:output-def-lookup",
 	   2, 1, 0, (SCM pap, SCM sym, SCM def),
@@ -70,7 +71,6 @@ LY_DEFINE (ly_output_description, "ly:output-description",
   Output_def *id = unsmob_output_def (output_def);
 
   SCM al = ly_module2alist (id->scope_);
-
   SCM ell = SCM_EOL;
   for (SCM s = al; scm_is_pair (s); s = scm_cdr (s))
     {
@@ -98,6 +98,21 @@ LY_DEFINE (ly_paper_outputscale, "ly:paper-outputscale",
   return scm_from_double (output_scale (b));
 }
 
+/*
+  Cannot put in scope, but need a separate function, since we don't
+  want to allow this in --safe.
+ */
+LY_DEFINE (ly_output_def_parser, "ly:output-def-parser",
+	   1, 0, 0, (SCM odef),
+	   "Return the parser where @var{odef} is coming from.")
+{
+  Output_def *b = unsmob_output_def (odef);
+  SCM_ASSERT_TYPE (b, odef, SCM_ARG1, __FUNCTION__, "paper");
+
+  return b->get_parser()->self_scm ();
+}
+
+
 LY_DEFINE (ly_make_output_def, "ly:make-output-def",
 	   0, 0, 0, (),
 	   "Make a output def.")
