@@ -14,8 +14,10 @@
 
 #include "dimensions.hh"
 #include "file-name.hh"
+#include "international.hh"
 #include "lookup.hh"
 #include "main.hh"
+#include "string-convert.hh"
 #include "warn.hh"
 
 #if HAVE_PANGO_FT2
@@ -60,11 +62,11 @@ Pango_font::~Pango_font ()
 }
 
 void
-Pango_font::register_font_file (String filename, String ps_name)
+Pango_font::register_font_file (std::string filename, std::string ps_name)
 {
   scm_hash_set_x (physical_font_tab_,
-		  scm_makfrom0str (ps_name.to_str0 ()),
-		  scm_makfrom0str (filename.to_str0 ()));
+		  scm_makfrom0str (ps_name.c_str ()),
+		  scm_makfrom0str (filename.c_str ()));
 }
 
 void
@@ -74,14 +76,14 @@ Pango_font::derived_mark () const
 }
 
 Stencil
-Pango_font::pango_item_string_stencil (PangoItem const *item, String str) const
+Pango_font::pango_item_string_stencil (PangoItem const *item, std::string str) const
 {
   const int GLYPH_NAME_LEN = 256;
   char glyph_name[GLYPH_NAME_LEN];
   PangoAnalysis const *pa = &(item->analysis);
   PangoGlyphString *pgs = pango_glyph_string_new ();
 
-  pango_shape (str.to_str0 () + item->offset,
+  pango_shape (str.c_str () + item->offset,
 	       item->length, (PangoAnalysis*) pa, pgs);
 
   PangoRectangle logical_rect;
@@ -142,7 +144,7 @@ Pango_font::pango_item_string_stencil (PangoItem const *item, String str) const
   char *file_name_as_ptr = 0;
   FcPatternGetString (fcpat, FC_FILE, 0, (FcChar8 **) & file_name_as_ptr);
 
-  String file_name;
+  std::string file_name;
   if (file_name_as_ptr)
     {
       /* Normalize file name.  */
@@ -154,28 +156,33 @@ Pango_font::pango_item_string_stencil (PangoItem const *item, String str) const
   if (!ps_name_str0)
     warning (_f ("no PostScript font name for font `%s'", file_name));
 
-  String ps_name;
+  std::string ps_name;
   if (!ps_name_str0
       && file_name != ""
-      && (file_name.index (".otf") >= 0
-	  || file_name.index (".cff") >= 0))
+      && (file_name.find (".otf") != NPOS
+	  || file_name.find (".cff") != NPOS))
     {
 
       /* UGH: kludge a PS name for OTF/CFF fonts.  */
-      String name = file_name;
-      int idx = max (file_name.index (".otf"),
-		     file_name.index (".cff"));
+      std::string name = file_name;
+      ssize idx = file_name.find (".otf");
+      if (idx == NPOS)
+	idx = file_name.find (".cff");
 
-      name = name.left_string (idx);
+      name = name.substr (0, idx);
 
-      int slash_idx = name.index_last ('/');
-      if (slash_idx >= 0)
-	name = name.right_string (name.length () - slash_idx - 1);
-
-      String initial = name.cut_string (0, 1);
-      initial.to_upper ();
-      name = name.nomid_string (0, 1);
-      name.to_lower ();
+      ssize slash_idx = name.rfind ('/');
+      if (slash_idx != NPOS)
+	{
+	  slash_idx ++; 
+	  name = name.substr (slash_idx,
+			      name.length () - slash_idx);
+	}
+      
+      std::string initial = name.substr (0, 1);
+      initial = String_convert::to_upper (initial);
+      name = name.substr (1, name.length () - 1);
+      name = String_convert::to_lower (name);
       ps_name = initial + name;
     }
   else if (ps_name_str0)
@@ -187,7 +194,7 @@ Pango_font::pango_item_string_stencil (PangoItem const *item, String str) const
       pango_fc_font_unlock_face (fcfont);
 
       SCM expr = scm_list_5 (ly_symbol2scm ("glyph-string"),
-			     scm_makfrom0str (ps_name.to_str0 ()),
+			     scm_makfrom0str (ps_name.c_str ()),
 			     scm_from_double (size),
 			     scm_from_bool (cid_keyed),
 			     ly_quote_scm (glyph_exprs));
@@ -206,11 +213,11 @@ Pango_font::physical_font_tab () const
 }
 
 Stencil
-Pango_font::text_stencil (String str) const
+Pango_font::text_stencil (std::string str) const
 {
   GList *items
     = pango_itemize (context_,
-		     str.to_str0 (),
+		     str.c_str (),
 		     0, str.length (), attribute_list_,
 		     NULL);
 
@@ -270,7 +277,7 @@ Pango_font::text_stencil (String str) const
       SCM exp
 	= scm_list_3 (ly_symbol2scm ("utf-8-string"),
 		      scm_makfrom0str (descr_string),
-		      scm_makfrom0str (str.to_str0 ()));
+		      scm_makfrom0str (str.c_str ()));
 
       g_free (descr_string);
 
