@@ -19,8 +19,8 @@ properties_to_pango_description (SCM chain, Real text_size)
   PangoFontDescription *description = 0;
   if (scm_is_string (name))
     {
-      String name_str = ly_scm2string (name);
-      description = pango_font_description_from_string (name_str.to_str0 ());
+      std::string name_str = ly_scm2string (name);
+      description = pango_font_description_from_string (name_str.c_str ());
     }
   else
     {
@@ -133,14 +133,14 @@ symbols_to_pango_font_description (SCM family,
 {
   PangoFontDescription *description = pango_font_description_new ();
 
-  String family_str = "roman";
+  std::string family_str = "roman";
   if (scm_is_symbol (family))
     family_str = ly_symbol2string (family);
   else if (scm_is_string (family))
     family_str = ly_scm2string (family);
 
   pango_font_description_set_family (description,
-				     family_str.to_str0 ());
+				     family_str.c_str ());
   pango_font_description_set_style (description,
 				    symbol_to_pango_style (style));
   pango_font_description_set_variant (description,
