@@ -67,7 +67,7 @@ dump_fields ()
   SCM fields = SCM_EOL;
   for (int i = dump_header_fieldnames_global.size (); i--;)
     fields
-      = scm_cons (ly_symbol2scm (dump_header_fieldnames_global[i].to_str0 ()),
+      = scm_cons (ly_symbol2scm (dump_header_fieldnames_global[i].c_str ()),
 		  fields);
   return fields;
 }
@@ -104,9 +104,9 @@ Paper_book::output (SCM output_channel)
   if (ly_is_module (header_))
     scopes = scm_cons (header_, scopes);
 
-  String mod_nm = "scm framework-" + output_backend_global;
+  std::string mod_nm = "scm framework-" + output_backend_global;
 
-  SCM mod = scm_c_resolve_module (mod_nm.to_str0 ());
+  SCM mod = scm_c_resolve_module (mod_nm.c_str ());
   if (make_print)
     {
       SCM func = scm_c_module_lookup (mod, "output-framework");
@@ -144,10 +144,10 @@ Paper_book::classic_output (SCM output)
   if (ly_is_module (header_0_))
     scopes = scm_cons (header_0_, scopes);
 
-  String format = output_backend_global;
-  String mod_nm = "scm framework-" + format;
+  std::string format = output_backend_global;
+  std::string mod_nm = "scm framework-" + format;
 
-  SCM mod = scm_c_resolve_module (mod_nm.to_str0 ());
+  SCM mod = scm_c_resolve_module (mod_nm.c_str ());
   SCM func = scm_c_module_lookup (mod, "output-classic-framework");
 
   func = scm_variable_ref (func);
@@ -216,7 +216,7 @@ Paper_book::score_title (SCM header)
 }
 
 void
-set_system_penalty (Paper_system *ps, SCM header)
+set_system_penalty (Prob *ps, SCM header)
 {
   if (ly_is_module (header))
     {
@@ -245,7 +245,9 @@ Paper_book::add_score_title (SCM header)
 	override settings from \paper {}
       */
       SCM props = paper_->lookup_variable (ly_symbol2scm ("score-title-properties"));
-      Paper_system *ps = new Paper_system (title, props);
+      Prob *ps = make_paper_system (props);
+      paper_system_set_stencil (ps, title);
+      
       systems_ = scm_cons (ps->self_scm (), systems_);
       ps->unprotect ();
       set_system_penalty (ps, header);
@@ -264,7 +266,8 @@ Paper_book::systems ()
   if (!title.is_empty ())
     {
       SCM props = paper_->lookup_variable (ly_symbol2scm ("book-title-properties"));
-      Paper_system *ps = new Paper_system (title, props);
+      Prob *ps = make_paper_system (props);
+      paper_system_set_stencil (ps, title);
       set_system_penalty (ps, header_);
 
       systems_ = scm_cons (ps->self_scm (), systems_);
@@ -285,7 +288,6 @@ Paper_book::systems ()
 	    header_0_ = header;
 	}
       else if (Music_output *mop = unsmob_music_output (scm_car (s)))
-
 	{
 	  if (Paper_score *pscore = dynamic_cast<Paper_score *> (mop))
 	    {
@@ -323,7 +325,8 @@ Paper_book::systems ()
 						    scm_car (s));
 	  
 	  // TODO: init props
-	  Paper_system *ps = new Paper_system (*unsmob_stencil (t), SCM_EOL);
+	  Prob *ps = make_paper_system (SCM_EOL);
+	  paper_system_set_stencil (ps, *unsmob_stencil (t));
 	  ps->set_property ("is-title", SCM_BOOL_T); 
 	  systems_ = scm_cons (ps->self_scm (), systems_);
 	  ps->unprotect ();
@@ -338,10 +341,10 @@ Paper_book::systems ()
   systems_ = scm_reverse (systems_);
 
   int i = 0;
-  Paper_system *last = 0;
+  Prob *last = 0;
   for (SCM s = systems_; s != SCM_EOL; s = scm_cdr (s))
     {
-      Paper_system *ps = unsmob_paper_system (scm_car (s));
+      Prob *ps = unsmob_prob (scm_car (s));
       ps->set_property ("number", scm_from_int (++i));
 
       if (last
