@@ -6,19 +6,21 @@
   (c) 1997--2006 Han-Wen Nienhuys <hanwen@xs4all.nl>
 */
 
-#include "all-font-metrics.hh"
-#include "warn.hh"
-#include "main.hh"
-#include "system.hh"
 #include "score-engraver.hh"
-#include "paper-score.hh"
-#include "paper-column.hh"
-#include "output-def.hh"
+
+#include "all-font-metrics.hh"
 #include "axis-group-interface.hh"
 #include "context-def.hh"
 #include "global-context.hh"
+#include "international.hh"
+#include "main.hh"
 #include "open-type-font.hh"
+#include "output-def.hh"
 #include "paper-column-engraver.hh"
+#include "paper-column.hh"
+#include "paper-score.hh"
+#include "system.hh"
+#include "warn.hh"
 
 Score_engraver::Score_engraver ()
 {
@@ -66,7 +68,7 @@ Score_engraver::initialize ()
 	     + "\n"
 	     + _ ("Music font has not been installed properly.")
 	     + "\n"
-	     + _f ("Search path `%s'", global_path.to_string ().to_str0 ())
+	     + _f ("Search path `%s'", global_path.to_string ().c_str ())
 	     + "\n"
 	     + _ ("Aborting"));
     }
@@ -78,6 +80,7 @@ Score_engraver::initialize ()
 
   Object_key const *sys_key = context ()->get_grob_key ("System");
   pscore_->typeset_system (new System (props, sys_key));
+  
   system_ = pscore_->root_system ();
   context ()->set_property ("rootSystem", system_->self_scm ());
 
