@@ -9,21 +9,23 @@
 #include "score.hh"
 
 #include <cstdio>
+
 using namespace std;
 
 #include "book.hh"
 #include "cpu-timer.hh"
 #include "global-context.hh"
+#include "international.hh"
 #include "lily-parser.hh"
 #include "lilypond-key.hh"
 #include "main.hh"
 #include "music.hh"
+#include "music.hh"
 #include "output-def.hh"
 #include "paper-book.hh"
 #include "paper-score.hh"
 #include "warn.hh"
 
-#include "music.hh"
 #include "ly-smobs.icc"
 
 Score::Score ()
@@ -119,7 +121,7 @@ default_rendering (SCM music, SCM outdef,
     }
 
   SCM context = ly_run_translator (music, scaled_def, key);
-
+  
   SCM output_as_scm = ly_format_output (context);
   Music_output *output = unsmob_music_output (output_as_scm);
 
@@ -231,3 +233,9 @@ Score::get_music () const
 {
   return music_;
 }
+
+void
+Score::add_output_def (Output_def *def)
+{
+  defs_.push (def);
+}
