@@ -8,22 +8,22 @@
 
 #include "system.hh"
 
-
 #include "align-interface.hh"
-#include "axis-group-interface.hh"
-#include "warn.hh"
-#include "main.hh"
-#include "paper-column.hh"
-#include "output-def.hh"
-#include "paper-score.hh"
-#include "warn.hh"
 #include "all-font-metrics.hh"
+#include "axis-group-interface.hh"
+#include "grob-array.hh"
+#include "international.hh"
+#include "main.hh"
+#include "output-def.hh"
+#include "paper-column.hh"
+#include "paper-score.hh"
+#include "paper-system.hh"
+#include "pointer-group-interface.hh"
 #include "spacing-interface.hh"
 #include "staff-symbol-referencer.hh"
-#include "paper-system.hh"
 #include "tweak-registration.hh"
-#include "grob-array.hh"
-#include "pointer-group-interface.hh"
+#include "warn.hh"
+#include "warn.hh"
 
 System::System (System const &src, int count)
   : Spanner (src, count)
@@ -190,7 +190,8 @@ System::get_paper_systems ()
 
       System *system = dynamic_cast<System *> (broken_intos_[i]);
       system->post_processing ();
-      scm_vector_set_x (lines, scm_from_int (i), system->get_paper_system ());
+      scm_vector_set_x (lines, scm_from_int (i),
+			system->get_paper_system ());
 
       if (be_verbose_global)
 	progress_indication (to_string (i) + "]");
@@ -373,12 +374,10 @@ System::get_paper_system ()
 		       scm_cons (ly_symbol2scm ("combine-stencil"),
 				 exprs));
 
-
-
   Grob *left_bound = this->get_bound (LEFT);
   SCM prop_init = left_bound->get_property ("line-break-system-details");
-  Paper_system *pl = new Paper_system (sys_stencil,
-				       prop_init);
+  Prob *pl = make_paper_system (prop_init);
+  paper_system_set_stencil (pl, sys_stencil);
   pl->set_property ("penalty",
 		    left_bound->get_property ("page-penalty"));
   
@@ -394,7 +393,9 @@ System::get_paper_system ()
 	}
       pl->set_property ("refpoint-Y-extent", ly_interval2scm (staff_refpoints));
     }
-  
+
+  pl->set_property ("system-grob", this->self_scm ()); 
+
   return pl->unprotect ();
 }
 
@@ -452,6 +453,12 @@ System::columns () const
   return columns;
 }
 
+Paper_score*
+System::paper_score () const
+{
+  return pscore_;
+}
+
 int
 System::get_rank () const
 {
@@ -469,6 +476,8 @@ get_root_system (Grob *me)
   return dynamic_cast<System*> (system_grob); 
 }
 
+
+
 ADD_INTERFACE (System, "system-interface",
 	       "This is the toplevel object: each object in a score "
 	       "ultimately has a System object as its X and Y parent. ",
