@@ -11,6 +11,7 @@
 
 #include "tfm-reader.hh"
 
+#include "international.hh"
 #include "string-convert.hh"
 #include "warn.hh"
 
@@ -19,7 +20,7 @@
   (1 << 20)
 static const Real fix_to_real (Fix f);
 
-Tex_font_metric_reader::Tex_font_metric_reader (String name)
+Tex_font_metric_reader::Tex_font_metric_reader (std::string name)
   : input_ (name)
 {
 
@@ -54,11 +55,11 @@ Tex_font_metric_reader::get_U32_fix_scaled ()
   return get_U32_fix () * info_.design_size;
 }
 
-String
+std::string
 Tex_font_metric_reader::get_bcpl_string ()
 {
   U8 length_u8 = input_.get_U8 ();
-  String str = input_.get_string (length_u8);
+  std::string str = input_.get_string (length_u8);
   return str;
 }
 
@@ -104,7 +105,7 @@ Tex_font_metric_reader::read_header ()
     /* Not using ngettext's plural feature here, as this message is
        more of a programming error.  */
     error (_f ("TFM header of `%s' has only %u word (s)",
-	       input_.name_string ().to_str0 (), header_length));
+	       input_.name_string ().c_str (), header_length));
 
   info_.checksum = input_.get_U32 ();
   info_.design_size = get_U32_fix ();
@@ -137,7 +138,7 @@ Tex_font_metric_reader::read_params ()
   if (header_.param_word_count > TFM_MAX_FONTDIMENS)
     {
       warning (_f ("%s: TFM file has %u parameters, which is more than the %u I can handle",
-		   input_.name_string ().to_str0 (),
+		   input_.name_string ().c_str (),
 		   header_.param_word_count,
 		   TFM_MAX_FONTDIMENS));
       header_.param_word_count = TFM_MAX_FONTDIMENS;
